CSIP Client 

This library provides a simple, yet powerful API for communicating with CSIP Restful endpoints. It supports:

* Service exploration and population of default service payloads
* The creation of pipelines of cascading CSIP service calls representing complex workflows
* Synchronous and asynchronous service execution 
* Payload data upload and retrieval

(requires Python 3.6)
